==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/PerformanceManagement/src/com/clustercontrol/performanceMGR/bean/QuartzConstant.java <==
/*
Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
*/
package com.clustercontrol.performanceMGR.bean;

import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;

import com.clustercontrol.performanceMGR.ejb.bmp.CollectorLocalHome;

/**
 * QuartzϢ饹
 *
 * @version 2.0.0
 * @since 2.0.0
 */
public class QuartzConstant {
	public static final String GROUP_COLLECT  = "PERF_COLLECT";
	public static final String GROUP_MONITOR  = "PERF_MONITOR";
	public static final String JNDI_NAME = CollectorLocalHome.JNDI_NAME;
	public static final String QUARTZ_NAME = getQuartzName();
	//public static final String JNDI_NAME_PERF = CollectorRunManagementHome.JNDI_NAME;
	public static final String JNDI_NAME_PERF_MNG ="CollectorRunController";
	public static final String METHOD_NAME_PERF_MNG = "managePresavePeriod";
	
	
	public static String getQuartzName() {
		// ǽͻեɤ߹
	    Properties properties = new Properties();
		
		try {
			String homedir = System.getProperty("jboss.server.home.dir");
			String propertyFile = homedir + File.separator + "conf" + File.separator + "performance.properties";
			
			// ץѥƥե뤫饭ͤΥꥹȤɤ߹ߤޤ
			properties.load(new FileInputStream(propertyFile));
		} catch (Exception e) {
			// 顼
			e.printStackTrace();
		}
		
		return properties.getProperty("QuartzJndiName");
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/PerformanceManagement/src/com/clustercontrol/performanceMGR/bean/QuartzConstant.java <==
/*
Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
*/
package com.clustercontrol.performanceMGR.bean;

import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;

import com.clustercontrol.performanceMGR.ejb.bmp.CollectorLocalHome;

/**
 * Quartz関連定数クラス
 *
 * @version 2.0.0
 * @since 2.0.0
 */
public class QuartzConstant {
	public static final String GROUP_COLLECT  = "PERF_COLLECT";
	public static final String GROUP_MONITOR  = "PERF_MONITOR";
	public static final String JNDI_NAME = CollectorLocalHome.JNDI_NAME;
	public static final String QUARTZ_NAME = getQuartzName();
	//public static final String JNDI_NAME_PERF = CollectorRunManagementHome.JNDI_NAME;
	public static final String JNDI_NAME_PERF_MNG ="CollectorRunController";
	public static final String METHOD_NAME_PERF_MNG = "managePresavePeriod";
	
	
	public static String getQuartzName() {
		// 性能値算出用設定ファイルを読み込む
	    Properties properties = new Properties();
		
		try {
			String homedir = System.getProperty("jboss.server.home.dir");
			String propertyFile = homedir + File.separator + "conf" + File.separator + "performance.properties";
			
			// プロパティファイルからキーと値のリストを読み込みます
			properties.load(new FileInputStream(propertyFile));
		} catch (Exception e) {
			// エラー処理
			e.printStackTrace();
		}
		
		return properties.getProperty("QuartzJndiName");
	}
}
